@@ -11,12 +11,17 @@ from .functions import (
     dependent_objects,
     drop_database,
     escape_like,
+    get_bind,
     get_columns,
     get_declarative_base,
+    get_mapper,
     get_primary_keys,
     get_referencing_foreign_keys,
     get_tables,
+    group_foreign_keys,
+    has_index,
     identity,
+    merge_references,
     mock_engine,
     naturally_equivalent,
     render_expression,
@@ -29,7 +34,6 @@ from .listeners import (
     force_auto_coercion,
     force_instant_defaults
 )
-from .merge import merge, Merger
 from .generic import generic_relationship
 from .proxy_dict import ProxyDict, proxy_dict
 from .query_chain import QueryChain
@@ -64,7 +68,7 @@ from .types import (
 )
 
 
-__version__ = '0.26.0'
+__version__ = '0.26.2'
 
 
 __all__ = (
@@ -82,14 +86,18 @@ __all__ = (
     force_instant_defaults,
     generates,
     generic_relationship,
+    get_bind,
     get_columns,
     get_declarative_base,
+    get_mapper,
     get_primary_keys,
     get_referencing_foreign_keys,
     get_tables,
+    group_foreign_keys,
+    has_index,
     identity,
     instrumented_list,
-    merge,
+    merge_references,
     mock_engine,
     naturally_equivalent,
     proxy_dict,
@@ -114,7 +122,6 @@ __all__ = (
     IPAddressType,
     JSONType,
     LocaleType,
-    Merger,
     NumericRangeType,
     Password,
     PasswordType,
