@@ -3,20 +3,27 @@ from .mock import create_mock_engine, mock_engine
 from .render import render_expression, render_statement
 from .sort_query import sort_query, QuerySorterException
 from .database import (
-    database_exists,
     create_database,
+    database_exists,
     drop_database,
     escape_like,
+    has_index,
     is_auto_assigned_date_column,
+)
+from .foreign_keys import (
+    dependent_objects,
+    get_referencing_foreign_keys,
+    group_foreign_keys,
     is_indexed_foreign_key,
+    merge_references,
     non_indexed_foreign_keys,
 )
 from .orm import (
-    dependent_objects,
+    get_bind,
     get_columns,
     get_declarative_base,
+    get_mapper,
     get_primary_keys,
-    get_referencing_foreign_keys,
     get_tables,
     getdotattr,
     has_changes,
@@ -34,12 +41,15 @@ __all__ = (
     'dependent_objects',
     'drop_database',
     'escape_like',
+    'get_bind',
     'get_columns',
     'get_declarative_base',
+    'get_mapper',
     'get_primary_keys',
     'get_referencing_foreign_keys',
     'get_tables',
     'getdotattr',
+    'group_foreign_keys',
     'has_changes',
     'identity',
     'is_auto_assigned_date_column',
