@@ -1,7 +1,5 @@
-from collections import defaultdict
 from sqlalchemy.engine.url import make_url
 import sqlalchemy as sa
-from sqlalchemy.schema import MetaData, Table, ForeignKeyConstraint
 from sqlalchemy.exc import ProgrammingError, OperationalError
 import os
 from copy import copy
@@ -9,12 +7,16 @@ from copy import copy
 
 def escape_like(string, escape_char='*'):
     """
-    Escapes the string paremeter used in SQL LIKE expressions
+    Escape the string paremeter used in SQL LIKE expressions.
 
-        >>> from sqlalchemy_utils import escape_like
-        >>> query = session.query(User).filter(
-        ...     User.name.ilike(escape_like('John'))
-        ... )
+    ::
+
+        from sqlalchemy_utils import escape_like
+
+
+        query = session.query(User).filter(
+            User.name.ilike(escape_like('John'))
+        )
 
 
     :param string: a string to escape
@@ -28,6 +30,69 @@ def escape_like(string, escape_char='*'):
     )
 
 
+def has_index(column):
+    """
+    Return whether or not given column has an index. A column has an index if
+    it has a single column index or it is the first column in compound column
+    index.
+
+    :param column: SQLAlchemy Column object
+
+    .. versionadded: 0.26.2
+
+    ::
+
+        from sqlalchemy_utils import has_index
+
+
+        class Article(Base):
+            __tablename__ = 'article_translation'
+            id = sa.Column(sa.Integer, primary_key=True)
+            title = sa.Column(sa.String(100))
+            is_published = sa.Column(sa.Boolean)
+            is_deleted = sa.Column(sa.Boolean)
+            is_archived = sa.Column(sa.Boolean)
+
+            __table_args__ = (
+            )
+
+
+        table = Article.__table__
+
+        has_index(table.c.is_published) # True
+        has_index(table.c.is_deleted)   # True
+        has_index(table.c.is_archived)  # False
+
+
+    Also supports primary key indexes
+
+    ::
+
+        from sqlalchemy_utils import has_index
+
+
+        class ArticleTranslation(Base):
+            __tablename__ = 'article_translation'
+            id = sa.Column(sa.Integer, primary_key=True)
+            locale = sa.Column(sa.String(10), primary_key=True)
+            title = sa.Column(sa.String(100))
+
+
+        table = ArticleTranslation.__table__
+
+        has_index(table.c.locale)   # False
+        has_index(table.c.id)       # True
+    """
+    return (
+        column is column.table.primary_key.columns.values()[0]
+        or
+        any(
+            index.columns.values()[0] is column
+            for index in column.table.indexes
+        )
+    )
+
+
 def is_auto_assigned_date_column(column):
     """
     Returns whether or not given SQLAlchemy Column object's is auto assigned
@@ -73,7 +138,10 @@ def database_exists(url):
 
     url = copy(make_url(url))
     database = url.database
-    url.database = None
+    if url.drivername.startswith('postgresql'):
+        url.database = 'template1'
+    else:
+        url.database = None
 
     engine = sa.create_engine(url)
 
@@ -123,7 +191,10 @@ def create_database(url, encoding='utf8'):
     url = copy(make_url(url))
 
     database = url.database
-    if not url.drivername.startswith('sqlite'):
+
+    if url.drivername.startswith('postgresql'):
+        url.database = 'template1'
+    elif not url.drivername.startswith('sqlite'):
         url.database = None
 
     engine = sa.create_engine(url)
@@ -134,7 +205,8 @@ def create_database(url, encoding='utf8'):
             engine.raw_connection().set_isolation_level(
                 ISOLATION_LEVEL_AUTOCOMMIT)
 
-        text = "CREATE DATABASE %s ENCODING = '%s'" % (database, encoding)
+        text = "CREATE DATABASE %s ENCODING '%s' TEMPLATE template0" % (
+            database, encoding)
         engine.execute(text)
 
     elif engine.dialect.name == 'mysql':
@@ -165,7 +237,10 @@ def drop_database(url):
     url = copy(make_url(url))
 
     database = url.database
-    if not url.drivername.startswith('sqlite'):
+
+    if url.drivername.startswith('postgresql'):
+        url.database = 'template1'
+    elif not url.drivername.startswith('sqlite'):
         url.database = None
 
     engine = sa.create_engine(url)
@@ -176,61 +251,20 @@ def drop_database(url):
     elif engine.dialect.name == 'postgresql' and engine.driver == 'psycopg2':
         from psycopg2.extensions import ISOLATION_LEVEL_AUTOCOMMIT
         engine.raw_connection().set_isolation_level(ISOLATION_LEVEL_AUTOCOMMIT)
+
+        # Disconnect all users from the database we are dropping.
+        text = '''
+        SELECT pg_terminate_backend(pg_stat_activity.pid)
+        FROM pg_stat_activity
+        WHERE pg_stat_activity.datname = '%s'
+          AND pid <> pg_backend_pid()
+        ''' % database
+        engine.execute(text)
+
+        # Drop the database.
         text = "DROP DATABASE %s" % database
         engine.execute(text)
 
     else:
         text = "DROP DATABASE %s" % database
         engine.execute(text)
-
-
-def non_indexed_foreign_keys(metadata, engine=None):
-    """
-    Finds all non indexed foreign keys from all tables of given MetaData.
-
-    Very useful for optimizing postgresql database and finding out which
-    foreign keys need indexes.
-
-    :param metadata: MetaData object to inspect tables from
-    """
-    reflected_metadata = MetaData()
-
-    if metadata.bind is None and engine is None:
-        raise Exception(
-            'Either pass a metadata object with bind or '
-            'pass engine as a second parameter'
-        )
-
-    constraints = defaultdict(list)
-
-    for table_name in metadata.tables.keys():
-        table = Table(
-            table_name,
-            reflected_metadata,
-            autoload=True,
-            autoload_with=metadata.bind or engine
-        )
-
-        for constraint in table.constraints:
-            if not isinstance(constraint, ForeignKeyConstraint):
-                continue
-
-            if not is_indexed_foreign_key(constraint):
-                constraints[table.name].append(constraint)
-
-    return dict(constraints)
-
-
-def is_indexed_foreign_key(constraint):
-    """
-    Whether or not given foreign key constraint's columns have been indexed.
-
-    :param constraint: ForeignKeyConstraint object to check the indexes
-    """
-    for index in constraint.table.indexes:
-        index_column_names = set(
-            column.name for column in index.columns
-        )
-        if index_column_names == set(constraint.columns):
-            return True
-    return False
