@@ -3,177 +3,107 @@ try:
 except ImportError:
     from ordereddict import OrderedDict
 from functools import partial
-from itertools import groupby
 from inspect import isclass
 from operator import attrgetter
 import sqlalchemy as sa
 from sqlalchemy import inspect
 from sqlalchemy.ext.hybrid import hybrid_property
+from sqlalchemy.orm import mapperlib
 from sqlalchemy.orm.attributes import InstrumentedAttribute
+from sqlalchemy.orm.exc import UnmappedInstanceError
 from sqlalchemy.orm.mapper import Mapper
 from sqlalchemy.orm.query import _ColumnEntity
 from sqlalchemy.orm.session import object_session
 from sqlalchemy.orm.util import AliasedInsp
-from ..query_chain import QueryChain
 
 
-def dependent_objects(obj, foreign_keys=None):
+def get_mapper(mixed):
     """
-    Return a QueryChain that iterates through all dependent objects for given
-    SQLAlchemy object.
+    Return related SQLAlchemy Mapper for given SQLAlchemy object.
 
-    Consider a User object is referenced in various articles and also in
-    various orders. Getting all these dependent objects is as easy as:
+    :param mixed: SQLAlchemy Table / Alias / Mapper / declarative model object
 
     ::
 
-        from sqlalchemy_utils import dependent_objects
+        from sqlalchemy_utils import get_mapper
 
 
-        dependent_objects(user)
+        get_mapper(User)
+
+        get_mapper(User())
+
+        get_mapper(User.__table__)
+
+        get_mapper(User.__mapper__)
+
+        get_mapper(sa.orm.aliased(User))
+
+        get_mapper(sa.orm.aliased(User.__table__))
 
 
-    If you expect an object to have lots of dependent_objects it might be good
-    to limit the results::
+    Raises:
+        ValueError: if multiple mappers were found for given argument
 
-
-        dependent_objects(user).limit(5)
-
-
-
-    The common use case is checking for all restrict dependent objects before
-    deleting parent object and inform the user if there are dependent objects
-    with ondelete='RESTRICT' foreign keys. If this kind of checking is not used
-    it will lead to nasty IntegrityErrors being raised.
-
-    In the following example we delete given user if it doesn't have any
-    foreign key restricted dependent objects.
-
-    ::
-
-
-        from sqlalchemy_utils import get_referencing_foreign_keys
-
-
-        user = session.query(User).get(some_user_id)
-
-
-        deps = list(
-            dependent_objects(
-                user,
-                (
-                    fk for fk in get_referencing_foreign_keys(User)
-                    # On most databases RESTRICT is the default mode hence we
-                    # check for None values also
-                    if fk.ondelete == 'RESTRICT' or fk.ondelete is None
-                )
-            ).limit(5)
-        )
-
-        if deps:
-            # Do something to inform the user
-            pass
-        else:
-            session.delete(user)
-
-
-    :param obj: SQLAlchemy declarative model object
-    :param foreign_keys:
-        A sequence of foreign keys to use for searching the dependent_objects
-        for given object. By default this is None, indicating that all foreign
-        keys referencing the object will be used.
-
-    .. note::
-        This function does not support exotic mappers that use multiple tables
-
-    .. seealso:: :func:`get_referencing_foreign_keys`
-
-    .. versionadded: 0.26.0
-    """
-    if foreign_keys is None:
-        foreign_keys = get_referencing_foreign_keys(obj)
-
-    session = object_session(obj)
-
-    foreign_keys = sorted(
-        foreign_keys, key=lambda key: key.constraint.table.name
-    )
-    chain = QueryChain([])
-    classes = obj.__class__._decl_class_registry
-
-    for table, keys in groupby(foreign_keys, lambda key: key.constraint.table):
-        for class_ in classes.values():
-            if hasattr(class_, '__table__') and class_.__table__ == table:
-                criteria = []
-                visited_constraints = []
-                for key in keys:
-                    if key.constraint not in visited_constraints:
-                        visited_constraints.append(key.constraint)
-                        subcriteria = [
-                            getattr(class_, column.key) ==
-                            getattr(
-                                obj,
-                                key.constraint.elements[index].column.key
-                            )
-                            for index, column
-                            in enumerate(key.constraint.columns)
-                        ]
-                        criteria.append(sa.and_(*subcriteria))
-
-                query = session.query(class_).filter(
-                    sa.or_(
-                        *criteria
-                    )
-                )
-                chain.queries.append(query)
-        return chain
-
-
-def get_referencing_foreign_keys(mixed):
-    """
-    Returns referencing foreign keys for given Table object or declarative
-    class.
-
-    :param mixed:
-        SA Table object or SA declarative class
-
-    ::
-
-        get_referencing_foreign_keys(User)  # set([ForeignKey('user.id')])
-
-        get_referencing_foreign_keys(User.__table__)
-
-
-    This function also understands inheritance. This means it returns
-    all foreign keys that reference any table in the class inheritance tree.
-
-    Let's say you have three classes which use joined table inheritance,
-    namely TextItem, Article and BlogPost with Article and BlogPost inheriting
-    TextItem.
-
-    ::
-
-        # This will check all foreign keys that reference either article table
-        # or textitem table.
-        get_referencing_foreign_keys(Article)
-
-    .. seealso:: :func:`get_tables`
+    .. versionadded: 0.26.1
     """
+    if isinstance(mixed, sa.orm.Mapper):
+        return mixed
+    if isinstance(mixed, sa.orm.util.AliasedClass):
+        return sa.inspect(mixed).mapper
+    if isinstance(mixed, sa.sql.selectable.Alias):
+        mixed = mixed.element
     if isinstance(mixed, sa.Table):
-        tables = [mixed]
+        mappers = [
+            mapper for mapper in mapperlib._mapper_registry
+            if mixed in mapper.tables
+        ]
+        if len(mappers) > 1:
+            raise ValueError(
+                "Multiple mappers found for table '%s'."
+                % mixed.name
+            )
+        elif not mappers:
+            raise ValueError(
+                "Could not get mapper for table '%s'."
+            )
+        else:
+            return mappers[0]
+    if not isclass(mixed):
+        mixed = type(mixed)
+    return sa.inspect(mixed)
+
+
+def get_bind(obj):
+    """
+    Return the bind for given SQLAlchemy Engine / Connection / declarative
+    model object.
+
+    :param obj: SQLAlchemy Engine / Connection / declarative model object
+
+    ::
+
+        from sqlalchemy_utils import get_bind
+
+
+        get_bind(session)  # Connection object
+
+        get_bind(user)
+
+    """
+    if hasattr(obj, 'bind'):
+        conn = obj.bind
     else:
-        tables = get_tables(mixed)
+        try:
+            conn = object_session(obj).bind
+        except UnmappedInstanceError:
+            conn = obj
 
-    referencing_foreign_keys = set()
-
-    for table in mixed.metadata.tables.values():
-        if table not in tables:
-            for constraint in table.constraints:
-                if isinstance(constraint, sa.sql.schema.ForeignKeyConstraint):
-                    for fk in constraint.elements:
-                        if any(fk.references(t) for t in tables):
-                            referencing_foreign_keys.add(fk)
-    return referencing_foreign_keys
+    if not hasattr(conn, 'execute'):
+        raise TypeError(
+            'This method accepts only Session, Engine, Connection and '
+            'declarative model objects.'
+        )
+    return conn
 
 
 def get_primary_keys(mixed):
